#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or (at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
# FILE:
# interbase/ResultSet.py
#
# DESCRIPTION:
# Driver to provide access to data via the Kinterbasdb Interbase/Firebird Python Driver
# Requires Kinterbasdb > 3.0 (http://kinterbasdb.sourceforge.net/)
#
# NOTES:
#

__all__ = ['ResultSet']

import string
from gnue.common.datasources.drivers import DBSIG2


#
#
#
class ResultSet(DBSIG2.ResultSet):

  def __init__(self, *args, **parms):
    self.conditions = parms['conditions']
    self.sql = parms['sql']
    del parms['conditions']
    del parms['sql']
    
    DBSIG2.ResultSet.__init__(self, *args, **parms)

    self._recordCount = self._dataObject._getQueryCount(self.conditions, self.sql)
